@@ -26,15 +26,14 @@
 #' @return Returns a list with metadata and spectra.
 #'
 #' @author Sebastian Gibb \email{mail@@sebastiangibb.de}
-#' @rdname parseMzMl
 #' @keywords internal
-#'
+#' @noRd
 .parseMzMl <- function(file, verbose=FALSE, ...) {
-  return(XML::xmlEventParse(file=file,
-                            handlers=.mzMlHandlers(fileName=file,
-                                                   verbose=verbose),
-                            addContext=FALSE, useTagName=TRUE, useDotNames=TRUE,
-                            ...)$getData())
+  XML::xmlEventParse(file=file,
+                     handlers=.mzMlHandlers(fileName=file,
+                                            verbose=verbose),
+                     addContext=FALSE, useTagName=TRUE, useDotNames=TRUE,
+                     ...)$getData()
 }
 
 #' Parse mzML files.
@@ -52,9 +51,8 @@
 #' @references
 #' Definition of \code{mzML} format:
 #' \url{http://www.psidev.info/mzml_1_0_0}
-#' @rdname mzMlHandlers
 #' @keywords internal
-#'
+#' @noRd
 .mzMlHandlers <- function(fileName, verbose=FALSE) {
   ## define local variables
 
@@ -90,9 +88,7 @@
     ## fetch version information
     mzMlVersion <<- readMzXmlData:::.grepDouble(attrs["xsi:schemaLocation"])
 
-    if (verbose) {
-      message("Found mzML document (version: ", mzMlVersion, ").")
-    }
+    .msg(verbose, "Found mzML document (version: ", mzMlVersion, ").")
   }
 
   ## mzML/referenceableParamGroupList/referenceableParamGroup
@@ -115,10 +111,8 @@
     nSpectra <<- readMzXmlData:::.attributeToDouble(attrs, "count",
                                                     required=TRUE)
 
-    if (verbose) {
-      message("Found ", nSpectra, " ",
-              ifelse(nSpectra == 1, "spectrum", "spectra"), ".")
-    }
+    .msg(verbose, "Found ", nSpectra, " ",
+         ifelse(nSpectra == 1, "spectrum", "spectra"), ".")
   }
 
   ## mzML/run/spectrumList/spectrum
@@ -145,10 +139,8 @@
                                                            "encodedLength")))
       xml$spectra[[curSpecIdx]]$metaData$imaging <<- list()
     }
-    if (verbose) {
-      message("Processing spectrum ", curSpecIdx, "/", nSpectra,
-              " (id: ", attrs["id"], ") ...")
-    }
+    .msg(verbose, "Processing spectrum ", curSpecIdx, "/", nSpectra,
+        " (id: ", attrs["id"], ") ...")
   }
 
   chromatogram <- function(name, attrs) {
@@ -220,9 +212,15 @@
       return()
     }
 
+    if (.isAttrSet(attrs, "IMS:1000090", "ibd MD5")) {
+      xml$ims$md5 <<-
+        readMzXmlData:::.attributeToString(attrs, "value")
+      return()
+    }
+
     if (.isAttrSet(attrs, "IMS:1000091", "ibd SHA-1")) {
       xml$ims$sha1 <<-
-        readMzXmlData:::.attributeToString(attrs, "value", required=TRUE)
+        readMzXmlData:::.attributeToString(attrs, "value")
       return()
     }
 
@@ -231,7 +229,7 @@
       return()
     }
 
-    if (.isAttrSet(attrs, "IMS:1000032", "processed")) {
+    if (.isAttrSet(attrs, "IMS:1000031", "processed")) {
       xml$ims$type <<- "processed"
       return()
     }
@@ -377,41 +375,25 @@
 
     ## sha1 sum for this file (from the beginning of the file up to (and
     ## including) the opening tag <fileChecksum>
-    if (verbose) {
-      message("Look for '<fileChecksum>' position ...")
-    }
+    .msg(verbose, "Look for '<fileChecksum>' position ...")
 
     ## 14 == nchar("<fileChecksum>")
     checkSumPos <- readMzXmlData:::.revfregexpr("<fileChecksum>", fileName) + 14
 
-    if (verbose) {
-      message("Calculating sha1-sum for ", sQuote(fileName), ": ",
-              appendLF=FALSE)
-    }
-
-    sha1Calc <- digest::digest(fileName, algo="sha1", file=TRUE,
-                               length=checkSumPos-1)
-    if (verbose) {
-      message(sha1Calc)
-    }
-
-    if (fileCheckSum != sha1Calc) {
-      warning("Stored and calculated Sha-1 sums do not match ",
-               "(stored ", sQuote(fileCheckSum), " calculated ",
-                sQuote(sha1Calc), ")!")
-    }
+    .testChecksum(fileName, fileCheckSum, algo="sha1", length=checkSumPos-1,
+                  verbose=verbose)
   }
 
   ## return statement (please call getData())
-  return(list(getData=function() {return(xml)},
-              mzML=mzML,
-              referenceableParamGroup=referenceableParamGroup,
-              referenceableParamGroupRef=referenceableParamGroupRef,
-              spectrumList=spectrumList,
-              spectrum=spectrum,
-              chromatogram=chromatogram,
-              cvParam=cvParam,
-              .startElement=.startElement,
-              .endElement=.endElement,
-              .text=.text))
+  list(getData=function() {return(xml)},
+       mzML=mzML,
+       referenceableParamGroup=referenceableParamGroup,
+       referenceableParamGroupRef=referenceableParamGroupRef,
+       spectrumList=spectrumList,
+       spectrum=spectrum,
+       chromatogram=chromatogram,
+       cvParam=cvParam,
+       .startElement=.startElement,
+       .endElement=.endElement,
+       .text=.text)
 }
